import io
import base64

DEFAULT_TEMPLATE = io.BytesIO(base64.b64decode(
"UEsDBBQABgAIAAAAIQATWPx6WgEAADwEAAATAAgCW0NvbnRlbnRfVHlwZXNdLnhtbCCiBAIooAACAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACsU8luwjAQvVfqP0S+Vomhh6qqCBy6HFsO9APceJK4"
"eJPHUPj7TkzhgNIgBJdY8fgtY7+ZzDZGZ2sIqJwt2bgYsQxs5aSyTck+F2/5I8swCiuFdhZKtgVks+ntzWSx9YAZoS2WrI3RP3GO"
"VQtGYOE8WKrULhgR6Tc03ItqKRrg96PRA6+cjWBjHjsONp28QC1WOmavG9reOSE4y5535zqpkgnvtapEJKO8q/JeXACNA8C1lUfu"
"8j9nBSETObbK493/Ct8emiMFZbrWUoFcfdB1BiUhm4sQ34Uh73yj+Y8Lyy/nlsVwaz0OXV2rCqSrVoZurUAfQEhsAaLRRVoLI5Td"
"ex7QT4eRp2V8ZSNdf4n4hI9IGQGevpdbSDQnBDFuNeCVu92RDinTe82D80hpD3C++j6WHTr3RAQhKjgEs++RD4o0KucLHqUMulmU"
"IHu0eZr96S8AAAD//wMAUEsDBBQABgAIAAAAIQB9zFSeDQEAAN0CAAALAAgCX3JlbHMvLnJlbHMgogQCKKAAAgAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAArJJNTsMwEIX3SNzBmn3jtCCEUJ1uEFJ3"
"CIUDTO1pYhL/yHYhvT2GRUOkElWCpT3j5+/Nm/VmMD17pxC1swKWRQmMrHRK20bAa/20uAcWE1qFvbMk4EgRNtX11fqFekz5UWy1"
"jyyr2CigTck/cB5lSwZj4TzZXNm7YDDlY2i4R9lhQ3xVlnc8/NSAaqLJtkpA2KobYPXR55//os0NJVSYkEsXaOFDJgtJZy+sxtBQ"
"EqCcfM7X8bujyNTAzwPdXg7k9nst6dHJgyGbznjmNCSyitQ8Eno/R7T8T6Ip8zifoecfLnQ757o5ltXlLL+vwhhXag9mZ1H3I8gp"
"qFOtePPUfMXFJ0tZfQIAAP//AwBQSwMEFAAGAAgAAAAhANA/ZN3hAAAALQIAABoACAF4bC9fcmVscy93b3JrYm9vay54bWwucmVs"
"cyCiBAEooAABAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAKyRz0oDQQzG74LvMOTuZreCiHS2FxF6lfoAw2z2D92dGSZp"
"dd/esGK1UPTSS+BLyJcfX9abj2k0R8o8xGChKkowFHxshtBZeNu93D2CYXGhcWMMZGEmhk19e7N+pdGJLnE/JDbqEthCL5KeENn3"
"NDkuYqKgkzbmyYnK3GFyfu86wlVZPmD+7QH1mafZNhbytqnA7Oakl//3jm07eHqO/jBRkAsn8D3mPfdEoqYudyQWTi3GZVIVSgx4"
"GWZ1TRjRkOgHZJG41D8Z7q/JwDKP+tFTGl/6OwI8e3L9CQAA//8DAFBLAwQUAAYACAAAACEA2xYhss0BAADpAgAADwAAAHhsL3dv"
"cmtib29rLnhtbIxSwW7bMAy9D9g/CLo7spU4a4PYRZbEWIBhKIauPasyHQuxJEOSZxfD/n20vXQddpkuokjxke+R27tBN+Q7OK+s"
"yWiyiCkBI22pzDmj3x6K6IYSH4QpRWMNZPQFPL3L37/b9tZdnq29EAQwPqN1CO2GMS9r0MIvbAsGI5V1WgR8ujPzrQNR+hog6Ibx"
"OF4zLZShM8LG/Q+GrSol4WBlp8GEGcRBIwK272vVeppvK9XA48yIiLb9IjT2PTSUNMKHY6kClBlN8Wl7+MvhuvZjpxqM8vg2iSnL"
"X1neO+Jr25/MZWeMDVO9jKJYogt2bzVS8/5eydChMQYwd1TnUUHv/8CMTzI8KVPafkp/eWP3k/tJlaHGDtJ1jPCz7xOocx1wPLcx"
"R2cQz1/HDpAF/sFK7E2pSV8sOd3ETOQLQFoJDnLU/oT80HYbhYY7lcmEcE2TopFIdrymj6sYDyXSGtk5h5rvMfKbIAzhsw/5Fm/S"
"OZXRHx9Svjymh2XE02IZ7dJjHCXrJY/Wq4Knqz3nq5T/vA5cD/9MXCvprLdVWEir2TxsXBLJYJAw7czNvDP5Vg+bnZP16UCKRpxR"
"cz7xwF5Qj2tn7Lql+S8AAAD//wMAUEsDBAoAAAAAAAAAIQAJtZ71REkAAERJAAAXAAAAZG9jUHJvcHMvdGh1bWJuYWlsLmpwZWf/"
"2P/gABBKRklGAAEBAQBIAEgAAP/hAHRFeGlmAABNTQAqAAAACAAEARoABQAAAAEAAAA+ARsABQAAAAEAAABGASgAAwAAAAEAAgAA"
"h2kABAAAAAEAAABOAAAAAAAAAEgAAAABAAAASAAAAAEAAqACAAQAAAABAAABAKADAAQAAAABAAAAlwAAAAD/7QA4UGhvdG9zaG9w"
"IDMuMAA4QklNBAQAAAAAAAA4QklNBCUAAAAAABDUHYzZjwCyBOmACZjs+EJ+/+IHuElDQ19QUk9GSUxFAAEBAAAHqGFwcGwCIAAA"
"bW50clJHQiBYWVogB9kAAgAZAAsAGgALYWNzcEFQUEwAAAAAYXBwbAAAAAAAAAAAAAAAAAAAAAAAAPbWAAEAAAAA0y1hcHBsAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAALZGVzYwAAAQgAAABvZHNjbQAAAXgAAAVsY3BydAAA"
"BuQAAAA4d3RwdAAABxwAAAAUclhZWgAABzAAAAAUZ1hZWgAAB0QAAAAUYlhZWgAAB1gAAAAUclRSQwAAB2wAAAAOY2hhZAAAB3wA"
"AAAsYlRSQwAAB2wAAAAOZ1RSQwAAB2wAAAAOZGVzYwAAAAAAAAAUR2VuZXJpYyBSR0IgUHJvZmlsZQAAAAAAAAAAAAAAFEdlbmVy"
"aWMgUkdCIFByb2ZpbGUAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAG1sdWMAAAAAAAAA"
"HgAAAAxza1NLAAAAKAAAAXhockhSAAAAKAAAAaBjYUVTAAAAJAAAAchwdEJSAAAAJgAAAex1a1VBAAAAKgAAAhJmckZVAAAAKAAA"
"Ajx6aFRXAAAAFgAAAmRpdElUAAAAKAAAAnpuYk5PAAAAJgAAAqJrb0tSAAAAFgAAAshjc0NaAAAAIgAAAt5oZUlMAAAAHgAAAwBk"
"ZURFAAAALAAAAx5odUhVAAAAKAAAA0pzdlNFAAAAJgAAAqJ6aENOAAAAFgAAA3JqYUpQAAAAGgAAA4hyb1JPAAAAJAAAA6JlbEdS"
"AAAAIgAAA8ZwdFBPAAAAJgAAA+hubE5MAAAAKAAABA5lc0VTAAAAJgAAA+h0aFRIAAAAJAAABDZ0clRSAAAAIgAABFpmaUZJAAAA"
"KAAABHxwbFBMAAAALAAABKRydVJVAAAAIgAABNBhckVHAAAAJgAABPJlblVTAAAAJgAABRhkYURLAAAALgAABT4AVgFhAGUAbwBi"
"AGUAYwBuAP0AIABSAEcAQgAgAHAAcgBvAGYAaQBsAEcAZQBuAGUAcgBpAQ0AawBpACAAUgBHAEIAIABwAHIAbwBmAGkAbABQAGUA"
"cgBmAGkAbAAgAFIARwBCACAAZwBlAG4A6AByAGkAYwBQAGUAcgBmAGkAbAAgAFIARwBCACAARwBlAG4A6QByAGkAYwBvBBcEMAQz"
"BDAEOwRMBD0EOAQ5ACAEPwRABD4ERAQwBDkEOwAgAFIARwBCAFAAcgBvAGYAaQBsACAAZwDpAG4A6QByAGkAcQB1AGUAIABSAFYA"
"QpAadSgAIABSAEcAQgAggnJfaWPPj/AAUAByAG8AZgBpAGwAbwAgAFIARwBCACAAZwBlAG4AZQByAGkAYwBvAEcAZQBuAGUAcgBp"
"AHMAawAgAFIARwBCAC0AcAByAG8AZgBpAGzHfLwYACAAUgBHAEIAINUEuFzTDMd8AE8AYgBlAGMAbgD9ACAAUgBHAEIAIABwAHIA"
"bwBmAGkAbAXkBegF1QXkBdkF3AAgAFIARwBCACAF2wXcBdwF2QBBAGwAbABnAGUAbQBlAGkAbgBlAHMAIABSAEcAQgAtAFAAcgBv"
"AGYAaQBsAMEAbAB0AGEAbADhAG4AbwBzACAAUgBHAEIAIABwAHIAbwBmAGkAbGZukBoAIABSAEcAQgAgY8+P8GWHTvZOAIIsACAA"
"UgBHAEIAIDDXMO0w1TChMKQw6wBQAHIAbwBmAGkAbAAgAFIARwBCACAAZwBlAG4AZQByAGkAYwOTA7UDvQO5A7oDzAAgA8ADwQO/"
"A8YDrwO7ACAAUgBHAEIAUABlAHIAZgBpAGwAIABSAEcAQgAgAGcAZQBuAOkAcgBpAGMAbwBBAGwAZwBlAG0AZQBlAG4AIABSAEcA"
"QgAtAHAAcgBvAGYAaQBlAGwOQg4bDiMORA4fDiUOTAAgAFIARwBCACAOFw4xDkgOJw5EDhsARwBlAG4AZQBsACAAUgBHAEIAIABQ"
"AHIAbwBmAGkAbABpAFkAbABlAGkAbgBlAG4AIABSAEcAQgAtAHAAcgBvAGYAaQBpAGwAaQBVAG4AaQB3AGUAcgBzAGEAbABuAHkA"
"IABwAHIAbwBmAGkAbAAgAFIARwBCBB4EMQRJBDgEOQAgBD8EQAQ+BEQEOAQ7BEwAIABSAEcAQgZFBkQGQQAgBioGOQYxBkoGQQAg"
"AFIARwBCACAGJwZEBjkGJwZFAEcAZQBuAGUAcgBpAGMAIABSAEcAQgAgAFAAcgBvAGYAaQBsAGUARwBlAG4AZQByAGUAbAAgAFIA"
"RwBCAC0AYgBlAHMAawByAGkAdgBlAGwAcwBldGV4dAAAAABDb3B5cmlnaHQgMjAwNyBBcHBsZSBJbmMuLCBhbGwgcmlnaHRzIHJl"
"c2VydmVkLgBYWVogAAAAAAAA81IAAQAAAAEWz1hZWiAAAAAAAAB0TQAAPe4AAAPQWFlaIAAAAAAAAFp1AACscwAAFzRYWVogAAAA"
"AAAAKBoAABWfAAC4NmN1cnYAAAAAAAAAAQHNAABzZjMyAAAAAAABDEIAAAXe///zJgAAB5IAAP2R///7ov///aMAAAPcAADAbP/A"
"ABEIAJcBAAMBEQACEQEDEQH/xAAfAAABBQEBAQEBAQAAAAAAAAAAAQIDBAUGBwgJCgv/xAC1EAACAQMDAgQDBQUEBAAAAX0BAgMA"
"BBEFEiExQQYTUWEHInEUMoGRoQgjQrHBFVLR8CQzYnKCCQoWFxgZGiUmJygpKjQ1Njc4OTpDREVGR0hJSlNUVVZXWFlaY2RlZmdo"
"aWpzdHV2d3h5eoOEhYaHiImKkpOUlZaXmJmaoqOkpaanqKmqsrO0tba3uLm6wsPExcbHyMnK0tPU1dbX2Nna4eLj5OXm5+jp6vHy"
"8/T19vf4+fr/xAAfAQADAQEBAQEBAQEBAAAAAAAAAQIDBAUGBwgJCgv/xAC1EQACAQIEBAMEBwUEBAABAncAAQIDEQQFITEGEkFR"
"B2FxEyIygQgUQpGhscEJIzNS8BVictEKFiQ04SXxFxgZGiYnKCkqNTY3ODk6Q0RFRkdISUpTVFVWV1hZWmNkZWZnaGlqc3R1dnd4"
"eXqCg4SFhoeIiYqSk5SVlpeYmZqio6Slpqeoqaqys7S1tre4ubrCw8TFxsfIycrS09TV1tfY2dri4+Tl5ufo6ery8/T19vf4+fr/"
"2wBDAAEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQH/2wBDAQEB"
"AQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQH/3QAEACD/2gAMAwEA"
"AhEDEQA/AP6lPD//AAiv9haR9q0HRZ7n+zrTz5prG3eWWXyULySuyFndm5Zick88ZrVctlte2t7fr/T36h/X9f0/yUep0nR9B12/"
"g0zR/Bulalf3L7YbW00m3lkbuzthAscUa5aWaUrDEgLyOigmn7v93TX7PQC3r3g6y8JftI/s4/DTU/DnhS50vxvZeOPEviGKLTkY"
"yXPh/wAOavb22iSq0a2l7paPqNvqMxljZ31SwtJIljitkeeG1Z2S30drN/n22vpfW+gH3T/wp74Vf9E68Gf+E7pf/wAYqAD/AIU9"
"8Kv+ideDP/Cd0v8A+MUAfmZ+078T/wDhVX7Rfw50/wAG/CDSL34CfDfV/A9h+1DrFp8J9H1nRobf406hP4a0KW78XSQi+8KzfCaK"
"bwz8RNZh0a3vP7a0LxTDBqUlvb2bK4B+mf8Awp74Vf8AROvBn/hO6X/8YoAP+FPfCr/onXgz/wAJ3S//AIxQB5bf/DH4dp8a/Cmj"
"J4H8LJpN18LfiDqdzpy6Jp4sp9QsfFnwztbK9lthD5T3VpbajfwW87KZIor25jQqszhgD1L/AIU98Kv+ideDP/Cd0v8A+MUAH/Cn"
"vhV/0TrwZ/4Tul//ABigD8mj8QtUtv8Agpvffs+XOmeCF+EB13SdBsvBMPw7+HurX01rqP7N8fxHGpNFZeHbb4i6Pp8fjWC8lu/i"
"Ve+I9R8D2Tx23w/utCi1bXdN1KyAP1l/4U98Kv8AonXgz/wndL/+MUAH/CnvhV/0TrwZ/wCE7pf/AMYoA8o8KfDL4d3XxV+LmmXP"
"gjwvPp2lWfw6fTbGXRNPe1sG1DSdYlvmtIGhMcDXckMUlwYgpmeNGfJUUAer/wDCnvhV/wBE68Gf+E7pf/xigCG5+EXwvit7iSD4"
"aeDLieOGV4bceH9Jj8+VEZo4fMaDanmuAm9uF3ZPAoA/Pj9hO78CfGjw1pPib4j+PfBniT41a14a1rUPiZ+zUPAnwr8MR/A7xBZe"
"KI7DUPD6+FbLwhYfFPR38GTGPwk99438S6xF4nM39vxrJ9ssJLcA/Q3/AIU98Kv+ideDP/Cd0v8A+MUAH/CnvhV/0TrwZ/4Tul//"
"ABigDyn4R/DL4d6rpfjOTUvBHha/ks/it8T9LtXu9E0+4e307TfGOp2un2MLSxMY7WytY47e1gTEUMKLHGqqoFAHq3/CnvhV/wBE"
"68Gf+E7pf/xigD5+/aw8MeF/hj+zB+0N8RvAXgTwXY+N/AnwX+JXi7wjet4M0LVhaeJPD3hDV9V0W5Ol3lhdWmoiHULW3kNjc21x"
"BdbfJlhkRmRgD55/Y4vdH+J3xF+MHhee78EfH34SeE/Bvwd1zwx8YV+G/gLRGtfiL4wsvFMvxF+FZ1vwL4d8PeDfGY8J2uk+Fdf+"
"26TpUWoeHf8AhLf7A166vLqO3MQB+g//AAp74Vf9E68Gf+E7pf8A8YoAZL8H/hWI5CPh14MyEcjHh3SxyFPcQAj8D+VAHm/wX+GH"
"w51j4QfCzVtV8DeFdR1PU/h54Nv9Rv7zQ9Pubu9vbvw9p891d3VxLC0s9xcTu8s0sjM8kjs7Ekk0Ael/8Ke+FX/ROvBn/hO6X/8A"
"GKAPkn9u3T9G+C/7Jnxm+J3wy8HeCdF8c+E9E0a70HVZPBvhfU0sJb3xb4f0q8uWs9b0rU9HYR6bf3hM+pafd2Vn/wAflxA8duwo"
"A9N/Z68FfCzxt8I/CniOax8B/EO8vU1Nb/xPaP8AC3xhFcXsGr30M9j/AMJH8MPCnhHwRqbaTsXTTNovh7TlX7N5d4kt+txcTgHt"
"P/CnvhV/0TrwZ/4Tul//ABigDwX9qX4deAvDX7N3x18Q+HvB3hvRNd0X4U+OdT0jWNL0awstR0zUbPw9fT2l9Y3dvEk9td20yJLB"
"PE6SRyKGVlIBoA//0P68fBX7JMPinwh4Z8SH4t+O9LOu6HpmrHTbLTPBslpYG+s4rg2ltJdaBPdPBAZDHE9zNLOyAGWR3JZq533/"
"AAA8k8Ofs9+Ffiz8VfjH8Fb/AMffHLQ9X+BUvw51a91O7l+H+m2HiOD4hWHiO/8AD2r6BceEN2prbQR+G78S22ujT7tJXglOnIwV"
"1Od9/wAAPZvCf7F3hr4W/EjwB4+sPiT8Q9e1+x1bUtI0648RXmn6s1hDqPhfxEbk2z39pdvGkixsslsCLeV3jnlRpra3eJXf/DWX"
"5f1+IH2d/wAI/r3/AEPGuf8Agt8Mf/KakAf8I/r3/Q8a5/4LfDH/AMpqAE/4R3XTkf8ACb63hvvf8Szwxzxjn/iTc8cc9higBf8A"
"hH9e/wCh41z/AMFvhj/5TUAH/CP69/0PGuf+C3wx/wDKagDiLrwhqD/EjQtTbxhrjalb+CPFljBd/YvDw8qxvNe8F3F1biEaSIH8"
"+4sbOUyvG00f2cLE6JLMrgHb/wDCP69/0PGuf+C3wx/8pqAD/hH9e/6HjXP/AAW+GP8A5TUAJ/wjuu53f8Jvre7GM/2Z4Yzj0z/Y"
"2ce1AC/8I/r3/Q8a5/4LfDH/AMpqAD/hH9e/6HjXP/Bb4Y/+U1AHCaF4Pv7fxz49v4PF+txX2oW/hFb+5+xeHnNytnYahHaAxPpB"
"hh8iOWRR5KKZN+ZSxC7QDu/+Ef17/oeNc/8ABb4Y/wDlNQAf8I/r3/Q8a5/4LfDH/wApqAI18NayjySp401hZJdnmyLpXhYPL5a7"
"U8xxogZ9i/Km4ttXgYBxQBJ/wj+vf9Dxrn/gt8Mf/KagA/4R/Xv+h41z/wAFvhj/AOU1AHC+AfCF/YWPiKOw8X63apceO/G19cqL"
"Pw9N519e+Ib64vbnM2jsyG4uJHlMSHyYt2yFUjVEoA7r/hH9e/6HjXP/AAW+GP8A5TUAH/CPa9/0PGuf+C3wx/8AKagBB4d11QAv"
"jfWwB0A0zwwB+AGjcf59aAF/4R/Xv+h41z/wW+GP/lNQA1/D+u7Hz441wja2R/ZvhjkY5/5g3pQBx3w58Jajp3w/8D6fpvjDXLTT"
"7Hwj4ds7G1Fl4dmFtaW2kWkNvAJp9IknlEUSKgkldpX27pGLEmgDs/8AhH9e/wCh41z/AMFvhj/5TUAB8Pa6Rg+ONcIPUHTfDBH/"
"AKZqAEXw7rijC+N9bUei6Z4YA/IaKP5fnQAv/CP69/0PGuf+C3wx/wDKagDy344eCrnXPg58UNG1zxXrmo6PqngTxPYanYG10C1F"
"5Y3WkXcNzbG5tNKhurcTROyGa3ljnj3bonVwGoA//9H+1X4aeP8Ax7YfD3wTZWPwR8aazZ2vhfRLe11a08SfDi3tdSgi0+BIr63g"
"1Dxfa30MNygWWOO7toLhEcCWKNwyUAeQfDO/0fT/AI6/Gv4leCPBvxF8WfEjxhB4c0L4p+FYvjL8DfENj4dHhN9RtfC1nceGNO8Z"
"m/8ADFxoi3OuafZLeSpK63mow3azzxo9uAfQlx448b6prng631L4OeLfD0MfiKaeO81HxF8PrmGedPDXiJFs0TS/FV7Os0kcksyP"
"LElvst5EaZZXhSUA9R/t7xD/ANCRq/8A4NvDH/y5oAP7e8Q/9CRq/wD4NvDH/wAuaAD+3vEP/Qkav/4NvDH/AMuaAD+3vEP/AEJG"
"r/8Ag28Mf/LmgA/t7xD/ANCRq/8A4NvDH/y5oA5a41rXv+E20mT/AIQ3VRIPC3iFBB/avhve6Nq3hhmlBGrmMLGyqjBnV2MqmNXV"
"ZCgB1P8Ab3iH/oSNX/8ABt4Y/wDlzQAf294h/wChI1f/AMG3hj/5c0AH9veIf+hI1f8A8G3hj/5c0AH9veIf+hI1f/wbeGP/AJc0"
"AH9veIf+hI1f/wAG3hj/AOXNAHKaTrWvL4q8Wuvg3VXd4vDu+Ean4cDQ7LO7Cl2bWBG3mgkqI2baFO/aSAwB1f8Ab3iH/oSNX/8A"
"Bt4Y/wDlzQAf294h/wChI1f/AMG3hj/5c0AH9veIf+hI1f8A8G3hj/5c0AH9veIf+hI1f/wbeGP/AJc0AH9veIf+hI1f/wAG3hj/"
"AOXNAHJ+ENa12O11oR+DtVmDeLPFDsU1Tw4ojd9ZumeE+Zq6EvExKMyho2IzGzIVagDrP7e8Q/8AQkav/wCDbwx/8uaAD+3vEP8A"
"0JGr/wDg28Mf/LmgA/t7xD/0JGr/APg28Mf/AC5oAP7e8Q/9CRq//g28Mf8Ay5oAa+u+ICjg+CNXwVbP/E28MDse/wDbJx9cfnig"
"Dm/BWt69H4P8KpH4M1WeNPDuiqkyar4bVJVGnW4EirJq8ciq4wwWRFdQQrqGBFAHTf294h/6EjV//Bt4Y/8AlzQAf294h/6EjV//"
"AAbeGP8A5c0AH9veIf8AoSNX/wDBt4Y/+XNAB/b3iH/oSNX/APBt4Y/+XNAHA/FXWdcm+GnjyKbwfqlrDJ4T15JbmTU/Dskdujad"
"cBpnjg1aSZ1jB3FIo3kYDCKWOGAP/9L+3n4WfE34dab8NvAen6h468JWV9Z+EtAtru0ufEGmQXNtcRabbpLBPDJdLJFNE4KSRuqu"
"jqVYBgRQB80/Bm3j0v8AaS+L/wAbfitqvwJsrnXtGvfAPwy1zwN8T7WQaV8LLPxdJ4i0vQdX8Hy+FNFEninxJqNxceLfGvi298U6"
"676v9k0LQ9P0/SrOS6vwD631T4i+AdX1fwbb6V4z8L6jPD4mkuZYbLXdOuZI7dPDHiSJpnSK4dliWSaKMuQFDyouSWVWAPQf+Eo8"
"N/8AQe0j/wAGNt/8coAP+Eo8N/8AQe0j/wAGNt/8coAP+Eo8N/8AQe0j/wAGNt/8coAP+Eo8N/8AQe0j/wAGNt/8coAP+Eo8N/8A"
"Qe0j/wAGNt/8coA5S48R+Hz440mYa3pRiXwp4hjZxf221ZH1fwwyIW8zAZ1RyqkZIRyM7TQB1f8AwlHhv/oPaR/4Mbb/AOOUAH/C"
"UeG/+g9pH/gxtv8A45QAf8JR4b/6D2kf+DG2/wDjlAB/wlHhv/oPaR/4Mbb/AOOUAH/CUeG/+g9pH/gxtv8A45QByWkeJPD6+LPF"
"8ja3pQjki8OCNzf2wVylneBwreZhtpI3Y6ZGetAHW/8ACUeG/wDoPaR/4Mbb/wCOUAH/AAlHhv8A6D2kf+DG2/8AjlAB/wAJR4b/"
"AOg9pH/gxtv/AI5QAf8ACUeG/wDoPaR/4Mbb/wCOUAH/AAlHhv8A6D2kf+DG2/8AjlAHI+DvEfh+K01sSa3pSF/F3iqRQ1/bAtHJ"
"rV2yOP3nKsuGU8ZByOuWAOu/4Sjw3/0HtI/8GNt/8coAP+Eo8N/9B7SP/Bjbf/HKAD/hKPDf/Qe0j/wY23/xygA/4Sjw3/0HtI/8"
"GNt/8coAa/ifw2Ucf29pGSrD/kI2vofWQD8z+VAHM+CPEfh+Hwb4Uil1vSkkj8OaKkiNqFsGR1062DKw8zIZTkMpwQcggEEUAdR/"
"wlHhv/oPaR/4Mbb/AOOUAH/CUeG/+g9pH/gxtv8A45QAf8JR4b/6D2kf+DG2/wDjlAB/wlHhv/oPaR/4Mbb/AOOUAeffFjxFoFx8"
"MvH8EGtaXNNN4R1+OKKO+t3kkkfTbhUREEmWdmwFVcliQACSBQB//9P+4f4UeBfBF98MvAN5e+DvCt3d3PhHQJ7m6uvD2kz3FxNJ"
"ptu0k080tm8kssjEs8kjs7sSzEk0AfKHw9WO1/bp+JHwl1e48K+KPAOsfBO4+JvhLw3FpHgbxFb+GdU0f4lWvhTXY9Sv7DwN4R1H"
"wbdRrrNjpWjeEJrj4gJqdnpupa1feKtL1GzbTtQAPtDV/Bvg/TNW8Fz6b4U8NafPJ4nkgeax0LS7WV4X8L+JXaJpILWJzGzxo7IW"
"KlkRiMqDQB339jaP/wBArTf/AABtv/jdAB/Y2j/9ArTf/AG2/wDjdAB/Y2j/APQK03/wBtv/AI3QAf2No/8A0CtN/wDAG2/+N0AH"
"9jaP/wBArTf/AABtv/jdAHJ3Gk6V/wAJzpEf9maf5Z8J+InKfYrbaXGseF1DEbMFgGYA44DEDGTQB1n9jaP/ANArTf8AwBtv/jdA"
"B/Y2j/8AQK03/wAAbb/43QAf2No//QK03/wBtv8A43QAf2No/wD0CtN/8Abb/wCN0AH9jaP/ANArTf8AwBtv/jdAHI6RpOlHxb4w"
"Q6Zp5VIfDexTZW2F3Wd4W2jZxkgZwOffFAHXf2No/wD0CtN/8Abb/wCN0AH9jaP/ANArTf8AwBtv/jdAB/Y2j/8AQK03/wAAbb/4"
"3QAf2No//QK03/wBtv8A43QAf2No/wD0CtN/8Abb/wCN0Ach4N0nSntNcL6Zp7FfF/itFLWVscImtXQRR8h+VQMKOwGBjAFAHX/2"
"No//AECtN/8AAG2/+N0AH9jaP/0CtN/8Abb/AON0AH9jaP8A9ArTf/AG2/8AjdAB/Y2j/wDQK03/AMAbb/43QA19H0gI5GlabkKx"
"H+g2vUD3jI/MfnQBzHgfSdKk8GeEnfTNOd28N6IWZrK2LMTpttksfLyWPUk5JPJJJJoA6n+xtH/6BWm/+ANt/wDG6AD+xtH/AOgV"
"pv8A4A23/wAboAP7G0f/AKBWm/8AgDbf/G6AD+xtH/6BWm/+ANt/8boA89+LWlaXF8MPiBJFpthHInhDX2SRLO3V0YabclWRlQMr"
"A8hgcg8jGKAP/9T+1T4aeH/jVP8AD3wTPo3xK8E6dpUvhfRJNOsLz4aahqN3Z2b6fAbe2ub+Px7YJeTQxbY5LlLK1WZwXECA7VAP"
"Ivh74sTUfjz8UfhJ8OPH3wnt/ihoWg6Z4z+JOu+Hv2e5dN07V5NS1rUtLey1DxdZePrdfEvibSdShmbXbR572fSJr+KO9ljvpriB"
"AD6Dn0L4u22ueD38RfEPwhqtm3iKZIINN+Hd9pU0V4fDXiJo7iSeXxzqKzQpEs8b2wiiZ3ljkE6iFo5wD1L+zvGX/Q06P/4Sk3/z"
"SUAH9neMv+hp0f8A8JSb/wCaSgA/s7xl/wBDTo//AISk3/zSUAH9neMv+hp0f/wlJv8A5pKAD+zvGX/Q06P/AOEpN/8ANJQBytxp"
"/iz/AITbSVPiXSjOfCviErL/AMIxKI1iGr+GA8Zh/wCEhJZ3cxssnmqEVGXy38zcgB1X9neMv+hp0f8A8JSb/wCaSgA/s7xl/wBD"
"To//AISk3/zSUAH9neMv+hp0f/wlJv8A5pKAD+zvGX/Q06P/AOEpN/8ANJQAf2d4y/6GnR//AAlJv/mkoA5PSdP8WnxV4uCeJdKW"
"VYvDvmyHwxKySZs7zy9kf/CQKYigyGzJIHOGGzBFAHWf2d4y/wChp0f/AMJSb/5pKAD+zvGX/Q06P/4Sk3/zSUAH9neMv+hp0f8A"
"8JSb/wCaSgA/s7xl/wBDTo//AISk3/zSUAH9neMv+hp0f/wlJv8A5pKAOT8Iaf4sa11ryfEulRAeLPFCyB/DEsu6ZdZuhLIpHiGP"
"Ykj5dYiGMYO3zJMF6AOs/s7xl/0NOj/+EpN/80lAB/Z3jL/oadH/APCUm/8AmkoAP7O8Zf8AQ06P/wCEpN/80lAB/Z3jL/oadH/8"
"JSb/AOaSgBr6d4x2PnxTpGNrZx4UmzjHOP8AipOuKAOa8Faf4tbwd4VaDxLpUULeHdGMcT+GJZXjQ6dblUaUeIoxIVHy7wibsZ2L"
"nbQB0/8AZ3jL/oadH/8ACUm/+aSgA/s7xl/0NOj/APhKTf8AzSUAH9neMv8AoadH/wDCUm/+aSgA/s7xl/0NOj/+EpN/80lAHAfF"
"Ww8VJ8NPHr3XiPS7i2XwlrzTwReGpbeSaIadcF40nOvziFnXKiUwy7M7vLfBVgD/1f7UPht8VtR0v4feCtNi+FfxM1OOx8L6Japq"
"On6Cs1hfLBp9vGLqzm84ebbTbfMgkwN8bKxAzigDxD4b+Cfg18OPjh4q+Lvw5+CnxW0jxxrfhLUPCviPQ7F7zUNNRdX8bX/jvXNZ"
"l0S81i9ax1bV/EeqSz38iJBbb23RW0Vxc3MtwAfSs3xN1DW9c8H2svwz+ImjCHxBPdi51bRUtreVo/DXiKP7NHIZyDcOJjKqkcxw"
"ykZK0Aeo/wDCV3f/AEKfiX/wFh/+OUAH/CV3f/Qp+Jf/AAFh/wDjlAB/wld3/wBCn4l/8BYf/jlAB/wld3/0KfiX/wABYf8A45QA"
"f8JXd/8AQp+Jf/AWH/45QBy9x4muj410mb/hF/EQZfC/iCLyjaxeYwfVvDLmRRvxsQoFfngyR4zk0AdR/wAJXd/9Cn4l/wDAWH/4"
"5QAf8JXd/wDQp+Jf/AWH/wCOUAH/AAld3/0KfiX/AMBYf/jlAB/wld3/ANCn4l/8BYf/AI5QAf8ACV3f/Qp+Jf8AwFh/+OUAcrpX"
"ia7TxT4tlHhfxExli8PAxraxb4vLtLsDzB5px5mcpgDIB64oA6r/AISu7/6FPxL/AOAsP/xygA/4Su7/AOhT8S/+AsP/AMcoAP8A"
"hK7v/oU/Ev8A4Cw//HKAD/hK7v8A6FPxL/4Cw/8AxygA/wCEru/+hT8S/wDgLD/8coA5Twj4luobXWQPDHiGXf4r8USkx20RCGTW"
"bpzE37ziSPOyQdnBA7UAdX/wld3/ANCn4l/8BYf/AI5QAf8ACV3f/Qp+Jf8AwFh/+OUAH/CV3f8A0KfiX/wFh/8AjlAB/wAJXd/9"
"Cn4l/wDAWH/45QA1vFN2VYf8In4l5Uj/AI9IT1GOnmjP0yPqM5oA5zwZ4muoPCHhaEeF/EUoj8O6MgljtYvLkC6dbASIfNOUcfMh"
"/iUg4GcKAdL/AMJXd/8AQp+Jf/AWH/45QAf8JXd/9Cn4l/8AAWH/AOOUAH/CV3f/AEKfiX/wFh/+OUAH/CV3f/Qp+Jf/AAFh/wDj"
"lAHBfFPxJdXPw18eW7eGfEFss3hPXo2uJ7aIQwhtNuAZZSJMrGn3nYZ2rk4OAKAP/9b+6D4R6vpMXwt+HsUuqadFLH4O8PJJHJe2"
"yOjrplsGR0aYMrKQQVYAg8EDkUAfLPwQ+Fms/Dv9qr45eOLHSPD2ifCnx/p2s6zca54h1DwHqHjjXPidrXjYateXHhvWPDs516D4"
"bz6CPNOheMmN/p+rpp8Wm4tobiKIA+w/EGq6XPqfgpYdSsJmXxU7lYry2kYKPC3icFiElYhQWUEkYBYA5yBQB2X220/5+rb/AMCI"
"aAD7baf8/Vt/4EQ0AH220/5+rb/wIhoAPttp/wA/Vt/4EQ0AH220/wCfq2/8CIaAOSuLy0/4TvSG+02+B4S8Rgnz4sZOseFiBnOM"
"kA4GMnB54xQB1v220/5+rb/wIhoAPttp/wA/Vt/4EQ0AH220/wCfq2/8CIaAD7baf8/Vt/4EQ0AH220/5+rb/wACIaAOQ0e8tB4u"
"8ZE3Nvgw+GsHz4sHFne5we+Pbp+NAHX/AG20/wCfq2/8CIaAD7baf8/Vt/4EQ0AH220/5+rb/wACIaAD7baf8/Vt/wCBENAB9ttP"
"+fq2/wDAiGgDj/Bl5ai013NzbjPjDxYRmeIcHW7sgjJOQRyCMA+nSgDsPttp/wA/Vt/4EQ0AH220/wCfq2/8CIaAD7baf8/Vt/4E"
"Q0AH220/5+rb/wACIaAGSXtn5cn+lW33G/5eIf7p+n8/yoA5jwLeWg8FeEgbq3BHhvRQQZ4gQRp1sCCDkgg5BB/TGKAOq+22n/P1"
"bf8AgRDQAfbbT/n6tv8AwIhoAPttp/z9W3/gRDQAfbbT/n6tv/AiGgDzv4uXdq3wu+IKrc27M3g/xAAqzxEknTbnAAGCSTwAP14F"
"AH//1/7Zfhh8GvhTrHw58Darqnw+8K3+o6h4V0O8vr250i1luLu6uNPt5Z7ieVkLSSyyMzu7HLMSTmgD4N/ZO1+0+J3x4+I/gL4o"
"fCnQbMx33xzutB8PWXhPw9DovgfQvhf8Z4fh14dsfEMkWnxa5ba74r8OXGmeJ9DudQvbm28SafcaxfWcaW9jbtQB+i178Jfhl4f1"
"rwbeaJ4F8M6Zcz+JJbSae00m1ikktZPDPiOV4HIT5o2kghkKnI3xo3VQVAPTP+EP8K/9C9o3/gutv/jdAB/wh/hX/oXtG/8ABdbf"
"/G6AD/hD/Cv/AEL2jf8Agutv/jdAB/wh/hX/AKF7Rv8AwXW3/wAboAP+EP8ACv8A0L2jf+C62/8AjdAHKXHhPwyPHGkwjQdIETeF"
"PEMrR/YLbY0ker+GERyuzBZVkdVJGQHYDG40AdX/AMIf4V/6F7Rv/Bdbf/G6AD/hD/Cv/QvaN/4Lrb/43QAf8If4V/6F7Rv/AAXW"
"3/xugA/4Q/wr/wBC9o3/AILrb/43QAf8If4V/wChe0b/AMF1t/8AG6AOT0nwp4ZfxX4vibQdIMcUXhwxobC2KoZLO8LlRswN5UFs"
"DnHOaAOs/wCEP8K/9C9o3/gutv8A43QAf8If4V/6F7Rv/Bdbf/G6AD/hD/Cv/QvaN/4Lrb/43QAf8If4V/6F7Rv/AAXW3/xugA/4"
"Q/wr/wBC9o3/AILrb/43QByXg/wp4ZmtdbMug6TIU8W+KYkL2FsxWOLWbpI0GY+FRAFVRwAMelAHW/8ACH+Ff+he0b/wXW3/AMbo"
"AP8AhD/Cv/QvaN/4Lrb/AON0AH/CH+Ff+he0b/wXW3/xugA/4Q/wr/0L2jf+C62/+N0AMk8H+FQjn/hHtG4Rj/yDrb0P/TOgDmvB"
"HhPwzN4N8KTS6BpEksvh3RpJHewtmd3bTrYs7sUJZmYksxOSTk5JoA6j/hD/AAr/ANC9o3/gutv/AI3QAf8ACH+Ff+he0b/wXW3/"
"AMboAP8AhD/Cv/QvaN/4Lrb/AON0AH/CH+Ff+he0b/wXW3/xugDz/wCK/hbw3a/DPx9cW+h6VBPB4S16WGaKxt0kikTTbhkkjdUD"
"K6sMqwOQeRigD//Q/tM+G3gX4i3vw+8FXmn/ABa8UaXY3XhjRZ7TTbex8FPb2FvJYQNDaQNd+DLq7aKCMrGjXN1dTkLmSeRjuoA8"
"18NeKb3VPjd4h+Dth47+Leh/EOLRNU8Salq+o/DzwDpmja9oXh3VLHQW1SDxJH4HY6jazX+oxQaNJdbPtqQ3xtAy2VyIgD3NvBXj"
"nTtf8HTa18UfFOtWcviCeBbaW08Gw+TO3hrxFJHdRvaeD7RzIixSQ7ZHkhMc8hMLSCOSIA9c/wCEe1D/AKHDxP8Al4Y/+ZugA/4R"
"7UP+hw8T/l4Y/wDmboAP+Ee1D/ocPE/5eGP/AJm6AD/hHtQ/6HDxP+Xhj/5m6AD/AIR7UP8AocPE/wCXhj/5m6AOVuNBv/8AhN9J"
"i/4SzxGWPhXxDIJiPDnmqF1fwwpjXHh4ReXIWVn3RtJujTY6KXVwDqv+Ee1D/ocPE/5eGP8A5m6AD/hHtQ/6HDxP+Xhj/wCZugA/"
"4R7UP+hw8T/l4Y/+ZugA/wCEe1D/AKHDxP8Al4Y/+ZugA/4R7UP+hw8T/l4Y/wDmboA5PSdCvm8VeLox4r8Rq0cXh3dKq+HPMl32"
"d4QJN3h9oz5eCE8uOM4Y7952mgDrP+Ee1D/ocPE/5eGP/mboAP8AhHtQ/wChw8T/AJeGP/mboAP+Ee1D/ocPE/5eGP8A5m6AD/hH"
"tQ/6HDxP+Xhj/wCZugA/4R7UP+hw8T/l4Y/+ZugDkvB+hX8lprRXxZ4jiC+LfFMZEY8OYdk1m6DSt5nh+Q+ZKcvJsKx7ifLjjTCK"
"Adb/AMI9qH/Q4eJ/y8Mf/M3QAf8ACPah/wBDh4n/AC8Mf/M3QAf8I9qH/Q4eJ/y8Mf8AzN0AH/CPah/0OHif8vDH/wAzdADX8P6g"
"Ec/8Jh4n4VjyPDHYf9i3QBzXgnQb+Xwd4UkXxZ4jhV/DuissUQ8N+XEDp1uRHH5nh2STYg+Vd7u+B8zsctQB0/8Awj2of9Dh4n/L"
"wx/8zdAB/wAI9qH/AEOHif8ALwx/8zdAB/wj2of9Dh4n/Lwx/wDM3QAf8I9qH/Q4eJ/y8Mf/ADN0AcB8VtDvoPhn49mfxV4iuUi8"
"Ja87W848PeROq6bcExS+RoEE/luPlfypopNpO11ODQB//9H+1L4a/F4aT8PfBOmf8K2+KWo/YPC+iWn2/TPDuk3GnXnkafBH9psZ"
"5fEUEk1rLt3wyPDEzxspMaklaAOU8A+JdC8J/EL4v+NW8IfGXxT4y+I2u6Ff6mL7w/4Ze78G+FtG8PWOleFvBGnWkHix5rDQLSeH"
"W/EcH2hIpNQ1fxJq9628MjUAeoT/ABT/ALe1zwfaL8PPiVpRh8RTXQn1nQtKs7eXy/DXiKM28MsWv3Ra5YTeakbIqGKKU+YGVUcA"
"9T/4SyT/AKFbxV/4Bad/8sqAD/hLJP8AoVvFX/gFp3/yyoAP+Esk/wChW8Vf+AWnf/LKgA/4SyT/AKFbxV/4Bad/8sqAD/hLJP8A"
"oVvFX/gFp3/yyoA5a48TufG2kzf8I14mBXwt4hi8o2dh5rb9W8MP5ij+0dpjTYFclgwaSPAYMxUA6n/hLJP+hW8Vf+AWnf8AyyoA"
"P+Esk/6FbxV/4Bad/wDLKgA/4SyT/oVvFX/gFp3/AMsqAD/hLJP+hW8Vf+AWnf8AyyoAP+Esk/6FbxV/4Bad/wDLKgDlNJ8Tuvir"
"xbJ/wjXiZjLF4dBjW0sDJHss7sAyD+0cAPkmPBOQrZAwCwB1f/CWSf8AQreKv/ALTv8A5ZUAH/CWSf8AQreKv/ALTv8A5ZUAH/CW"
"Sf8AQreKv/ALTv8A5ZUAH/CWSf8AQreKv/ALTv8A5ZUAH/CWSf8AQreKv/ALTv8A5ZUAcn4Q8TvFa60B4b8Sy7/FniiXMVpYEIZN"
"ZunMT51EESxk7JAOAwOCRgsAdZ/wlkn/AEK3ir/wC07/AOWVAB/wlkn/AEK3ir/wC07/AOWVAB/wlkn/AEK3ir/wC07/AOWVAB/w"
"lkn/AEK3ir/wC07/AOWVADX8VyFHH/CLeKuVYf8AHlp3cH/qJj+f5UAc34L8TyQ+D/CsX/CNeJpfL8O6MnmRWdgYpNunWw3xltRV"
"ijfeQsqkqQSqk7aAOm/4SyT/AKFbxV/4Bad/8sqAD/hLJP8AoVvFX/gFp3/yyoAP+Esk/wChW8Vf+AWnf/LKgA/4SyT/AKFbxV/4"
"Bad/8sqAOB+KviZ7n4aePID4c8SW4m8J67GZ7i0sVghD6dcL5kzR38jrGmdzlEZgoJCk8UAf/9L+6T4Ralp0fwt+Hkcl/ZRyJ4N8"
"PK6PdQq6MNLtsqylwVYHggjIPBxzQB8Bfsw/BP4teAf2w/jf8WPGsWnWvg7xx/wuFY7ifxHpl9Zwv4i+K+jeI/Ap8Gm2kXWLyx1f"
"wjYtd+LbTxf57eFPEFomleDZINAv7i3UA/RrxDqFhNqfgpYr6zkZfFTsRHcwuQo8LeJwWIVyQMkDJ4yQOMg0Adh9ptv+fmD/AL+x"
"/wDxygA+023/AD8wf9/Y/wD45QAfabb/AJ+YP+/sf/xygA+023/PzB/39j/+OUAH2m2/5+YP+/sf/wAcoA5K4uLf/hO9HP2iHb/w"
"iXiMZ81MZ/tjwrx9/qQPXnHTjNAHW/abb/n5g/7+x/8AxygA+023/PzB/wB/Y/8A45QAfabb/n5g/wC/sf8A8coAPtNt/wA/MH/f"
"2P8A+OUAH2m2/wCfmD/v7H/8coA5DR7i3/4S7xkftEODD4awfNTBxZXucfOM4yM4J/CgDr/tNt/z8wf9/Y//AI5QAfabb/n5g/7+"
"x/8AxygA+023/PzB/wB/Y/8A45QAfabb/n5g/wC/sf8A8coAPtNt/wA/MH/f2P8A+OUAcf4MuLcWmuZuIRnxh4sIzKg4Ot3WD98c"
"Ecj1HPOc0Adh9ptv+fmD/v7H/wDHKAD7Tbf8/MH/AH9j/wDjlAB9ptv+fmD/AL+x/wDxygA+023/AD8wf9/Y/wD45QAyS5tijj7R"
"Byjf8tY/Q/8ATQfz/KgDmPAtxbjwV4RBuIAR4a0TIMseR/xLbbg/vOvr0x3A6UAdV9ptv+fmD/v7H/8AHKAD7Tbf8/MH/f2P/wCO"
"UAH2m2/5+YP+/sf/AMcoAPtNt/z8wf8Af2P/AOOUAed/Fy4t2+F3xCVZ4WY+D/EAAEqEknTLnAADkknsAOenFAH/0/7Yfhj8FvhT"
"rHw68D6rqfgLw5fajqPhbRL2+vLjT45J7q7udPglnnmc8tJLIzO7HqxPtQB8LfArWLzxT+114u+Bvj/4U+AbrQoNA+NniSaPQtF8"
"KXOmeArDwJ8WPD/hH4VrB4g0HVL/AFW/l+IXgnW7jVdesPGlppWsad4o0XVLTSbUWFjeogB+ht58Ifhl4f1vwbeaL4I8P6bdTeI5"
"rOWa20+KN5LWTwz4ilkgY942lghkI/vxIeqigD03/hDfCn/Qv6X/AOAsdAB/whvhT/oX9L/8BY6AD/hDfCn/AEL+l/8AgLHQAf8A"
"CG+FP+hf0v8A8BY6AD/hDfCn/Qv6X/4Cx0AcrceEvDA8b6TANC00RN4V8QytH9mTa0iav4YRHI/vIsjqp7B29aAOq/4Q3wp/0L+l"
"/wDgLHQAf8Ib4U/6F/S//AWOgA/4Q3wp/wBC/pf/AICx0AH/AAhvhT/oX9L/APAWOgA/4Q3wp/0L+l/+AsdAHJ6T4S8Mv4r8XRNo"
"WmtHDD4c8pDbR7Y/Ms7xn2jAxuYAnk5PPFAHWf8ACG+FP+hf0v8A8BY6AD/hDfCn/Qv6X/4Cx0AH/CG+FP8AoX9L/wDAWOgA/wCE"
"N8Kf9C/pf/gLHQAf8Ib4U/6F/S//AAFjoA5Lwf4S8MTWutmXQtNcp4t8UxKWtUJWOLWbpI0H+yiAKo7AYoA63/hDfCn/AEL+l/8A"
"gLHQAf8ACG+FP+hf0v8A8BY6AD/hDfCn/Qv6X/4Cx0AH/CG+FP8AoX9L/wDAWOgBr+DfCoRyPD+l5CsR/osfofr/AC/OgDmvBPhH"
"wxP4O8KTTaFpsksvh3RpJJGtoyzu+nW5ZmPGWYkknueTnrQB0/8AwhvhT/oX9L/8BY6AD/hDfCn/AEL+l/8AgLHQAf8ACG+FP+hf"
"0v8A8BY6AD/hDfCn/Qv6X/4Cx0Aef/Fbwp4atfhn49uLfQ9Ogng8Ja9LDNHbIskUkenXDJIjDlWVgCpHIPIoA//U/sn02P4r+Evg"
"fp3ju0+JV/NoXh/4fWfiGLwtoHw68K6tri6VYaPFdnT9Pl1bVNKt7+7gtIyFlvr60E5jZ5ZVYkMAfN837UWneFf+EB1+y+Iut2tn"
"8XPhz8IvjX4m8Rab8Fvh/ax+BvBHx08U6X4I+GviP4ly/wDCQW95JPrni3V10maDQY/Et3p0VhrGq3arpll9olAPt6bwt8U7DXPC"
"EuvfFWDXbR/EM0MNrH4H0TTGhum8N+IWS68+CWRnCRJPEYWUofP8zh41KgHqn9j+K/8AocD/AOCPTf8A43QAf2P4r/6HA/8Agj03"
"/wCN0AH9j+K/+hwP/gj03/43QAf2P4r/AOhwP/gj03/43QAf2P4r/wChwP8A4I9N/wDjdAHLXGleJ/8AhNdJjPivMp8LeIHWb+xd"
"OBWMat4ZDx7dm0iRmRtxBZfLwCA7BgDqf7H8V/8AQ4H/AMEem/8AxugA/sfxX/0OB/8ABHpv/wAboAP7H8V/9Dgf/BHpv/xugA/s"
"fxX/ANDgf/BHpv8A8boAP7H8V/8AQ4H/AMEem/8AxugDlNJ0rxOfFXi1V8VlZEi8O+ZJ/YunHzQ1nd7BtKlV8sAj5Qud2TnigDq/"
"7H8V/wDQ4H/wR6b/APG6AD+x/Ff/AEOB/wDBHpv/AMboAP7H8V/9Dgf/AAR6b/8AG6AD+x/Ff/Q4H/wR6b/8boAP7H8V/wDQ4H/w"
"R6b/APG6AOT8IaV4ne11ryvFZiC+LPFCMP7F01t8i6zdCSUkoSPMfL7eig7RgDFAHWf2P4r/AOhwP/gj03/43QAf2P4r/wChwP8A"
"4I9N/wDjdAB/Y/iv/ocD/wCCPTf/AI3QAf2P4r/6HA/+CPTf/jdADX0jxUFYnxgcBTn/AIkWmHjHoUAP0Jwe+KAOc8F6V4mfwf4W"
"eHxYYom8O6M0cX9iaafLQ6dbbYwxVmbYMLvYlnxub5i1AHS/2P4r/wChwP8A4I9N/wDjdAB/Y/iv/ocD/wCCPTf/AI3QAf2P4r/6"
"HA/+CPTf/jdAB/Y/iv8A6HA/+CPTf/jdAHA/FTS/EsXw18eSXHik3MCeE9daa3/sbT4vPiGnXBeLzUQPH5i5XzEO9M7lwwoA/9X+"
"yaz+JGgax8BbX4e2E/jjRdd1T4bw+FU1uD4P/EHxVpthc3miLplxd26WGix2OtQokkpge11D7NOfLkSd05YA+N5P2ZfAF9oHwt8O"
"ax8RPixdaX4P+EHwQ+BXxJitf2d/H9m3xD+H37OvxLsviV8L4LeRtCuX8I65HqdpLpPijUoDqMWt6VqN9Ha2Wk3gs7q0AP0cuPi/"
"4T8Ra54Ps9OsfHCTQeIprx/7R+HPjvSImij8NeIomWKfU/D9vDNOWnQrbRO07RrLKsZjhlZAD1L/AITLSv8Any8Sf+Er4j/+VNAB"
"/wAJlpX/AD5eJP8AwlfEf/ypoAP+Ey0r/ny8Sf8AhK+I/wD5U0AH/CZaV/z5eJP/AAlfEf8A8qaAD/hMtK/58vEn/hK+I/8A5U0A"
"crceLtMPjfSZvsfiHYvhXxBEVPhnxAJSz6v4ZcFYv7M81kAjIeRUKIxRWZWdAwB1X/CZaV/z5eJP/CV8R/8AypoAP+Ey0r/ny8Sf"
"+Er4j/8AlTQAf8JlpX/Pl4k/8JXxH/8AKmgA/wCEy0r/AJ8vEn/hK+I//lTQAf8ACZaV/wA+XiT/AMJXxH/8qaAOT0nxdpi+KvF0"
"ptPEBWWLw6FC+GdfaRfLs7wN5ka6YZI85BQyIgcZKF8NsAOs/wCEy0r/AJ8vEn/hK+I//lTQAf8ACZaV/wA+XiT/AMJXxH/8qaAD"
"/hMtK/58vEn/AISviP8A+VNAB/wmWlf8+XiT/wAJXxH/APKmgA/4TLSv+fLxJ/4SviP/AOVNAHJ+EPFumQ2utBrTxAxfxZ4olHl+"
"GdflAWXWbp1VjHpjhZADiSNtskbZSRFcMKAOs/4TLSv+fLxJ/wCEr4j/APlTQAf8JlpX/Pl4k/8ACV8R/wDypoAP+Ey0r/ny8Sf+"
"Er4j/wDlTQAf8JlpX/Pl4k/8JXxH/wDKmgBr+MtLKOPsXiTJVh/yKviPuP8AsFD+f5UAc14K8XaZB4O8KwvZ+IS0Xh3RkYx+GPEE"
"sZK6dbglJY9MeORD1V0dkYYKkqRQB0//AAmWlf8APl4k/wDCV8R//KmgA/4TLSv+fLxJ/wCEr4j/APlTQAf8JlpX/Pl4k/8ACV8R"
"/wDypoAP+Ey0r/ny8Sf+Er4j/wDlTQBwHxV8V6bdfDTx7bR2mvrJP4S16JGn8N69bwqz6dcKDLPPpkcMMYJy0ksiIg5ZgBlQD//W"
"/tfvtNn1b9kyXS7XR/EGvXuo/BmOzsdH8K3TWHiLUL658NpFYQaTeLqeiG3uXungZZf7VsQIw+bgKfmAPkTRPC/xnt/DP/BL291H"
"4bfGOTxZ8K00bRPj4BqukyLo+n2XwF8VfDfXJfGNt/wnK6f4kF78Tbzwxr9pfW8OvXz6PaT66hgnheynAP0o8SKP7S8E4HTxY54H"
"/Uq+KOaAOsoAKACgAoAKAOSuAf8AhO9HPOP+ES8SDPbP9seFc/jjFAHW0AFABQAUAFAHH6P/AMjd4y/64+Gv/SK9oA7CgAoAKACg"
"AoA4/wAFgi01zIPPjHxaR7j+3Lzkf57exoA7CgAoAKACgBkgyjgckowAHfg0Acx4FBHgrwiCCD/wjWh8Hg/8g229fb/PNAHVUAFA"
"BQAUAedfF3/klvxD/wCxO8Q/pplxQB//1/7Fpfg/4Mtv2eH8d6TodlJ4ytPhcfFFrceIfEHjc+H5dWtPD/8AabNqWn6L4q0eUWcr"
"xOGt9PutP27gsMkKD5QD5WtdcsfEPhv9ibWPCGg/D/VvGf7Rfg34O+OPHHwhGs/Ek6xYeC/F9joGo/FP4i6b4uf4qQ2ng7wn4Cs9"
"Z+z+Hodd8PeIrzxZ4obT/CVnPPqOoE2gB+hE/wAEfhr4a1zwfe6PoV3BcXHiGaxmabxF4mvUa2l8NeIZnTyb7WbmIN5tvCwkWMSL"
"sKhgrOGAPUv+EA8J/wDQLP8A4Haj/wDJdAB/wgHhP/oFn/wO1H/5LoAP+EA8J/8AQLP/AIHaj/8AJdAB/wAIB4T/AOgWf/A7Uf8A"
"5LoAP+EA8J/9As/+B2o//JdAHLT+B/C48a6VbjTT5T+FvEEzL9t1DJkj1bwyiHP2vI2rLIMAAHdk7sLtAOp/4QDwn/0Cz/4Haj/8"
"l0AH/CAeE/8AoFn/AMDtR/8AkugA/wCEA8J/9As/+B2o/wDyXQAf8IB4T/6BZ/8AA7Uf/kugA/4QDwn/ANAs/wDgdqP/AMl0Acpp"
"Xgfww/irxbC2mkxwReHTEv22/G3zbS8Z+RdBjkqD8xOO2OaAOr/4QDwn/wBAs/8AgdqP/wAl0AH/AAgHhP8A6BZ/8DtR/wDkugA/"
"4QDwn/0Cz/4Haj/8l0AH/CAeE/8AoFn/AMDtR/8AkugA/wCEA8J/9As/+B2o/wDyXQBynhHwR4YuLXWjLpxYxeK/FECf6bfjEUOs"
"XSRr8t0M7VAGTlieSc5oA6v/AIQDwn/0Cz/4Haj/APJdAB/wgHhP/oFn/wADtR/+S6AD/hAPCf8A0Cz/AOB2o/8AyXQAf8IB4T/6"
"BZ/8DtR/+S6AGv4B8KBHP9lk4Vjg32o84BPa7z+VAHN+C/A/he58H+FriXTC0s3h7RpJGF7qA3SPp9uXbAugBuYk4A2jOBgYoA6b"
"/hAPCf8A0Cz/AOB2o/8AyXQAf8IB4T/6BZ/8DtR/+S6AD/hAPCf/AECz/wCB2o//ACXQAf8ACAeE/wDoFn/wO1H/AOS6AOC+Kngr"
"w1ZfDXx5d22nGO4tvCevTQv9sv32SR6dcMjbXuijbWAO1gynGGVgdtAH/9D+xtv+Fj2f7PkOoeJ5PhJrvwutPhxaXureHNV+E3j3"
"4g6lfeF7bSYriSy1Dw7oviq4PiW5FpGDdW1hoTRTuski2cUKkIAfP1xqXw10iw/Zl8bj4b/s3L4d+IsHw4tvgB48sf2T/E8mjeEm"
"+JGq2uufDfSItTh8Um+8AXeta/rsGo2VlbWkCaTqt7LqmqtpqCa+oA+4Li1+Na654PPibXfhdPYnxFMIF0Pwl4ss7pL3/hGvERie"
"Z7/xvfxSWohFwskSRxSmRoXWdUjdHAPUvs/jn/oLeE//AAntY/8AmooAPs/jn/oLeE//AAntY/8AmooAPs/jn/oLeE//AAntY/8A"
"mooAPs/jn/oLeE//AAntY/8AmooAPs/jn/oLeE//AAntY/8AmooA5W4g8af8JvpIOqeF/P8A+EV8QFHGg6sIhENX8M+YrRf8JGXa"
"RnMRSQTKqKsimJy6ugB1X2fxz/0FvCf/AIT2sf8AzUUAH2fxz/0FvCf/AIT2sf8AzUUAH2fxz/0FvCf/AIT2sf8AzUUAH2fxz/0F"
"vCf/AIT2sf8AzUUAH2fxz/0FvCf/AIT2sf8AzUUAcnpMHjT/AISrxcE1TwuJhF4d85m0HVWjYGzvPK8qMeI1aMqNwcvLLvJBUIBh"
"gDrPs/jn/oLeE/8AwntY/wDmooAPs/jn/oLeE/8AwntY/wDmooAPs/jn/oLeE/8AwntY/wDmooAPs/jn/oLeE/8AwntY/wDmooAP"
"s/jn/oLeE/8AwntY/wDmooA5PwhB4zNrrXk6p4YQDxZ4oEnm6DqshaYazdec6FPEkYWJpMmONgzonytJIRvYA6z7P45/6C3hP/wn"
"tY/+aigA+z+Of+gt4T/8J7WP/mooAPs/jn/oLeE//Ce1j/5qKAD7P45/6C3hP/wntY/+aigBklv458t/+Jt4T+43/Mvax6f9jRQB"
"zfgmDxofB3hUwap4XSE+HdGMSS6Dq0kqxnT7fYskieJIkdwuA7rFGrNyI0BCqAdP9n8c/wDQW8J/+E9rH/zUUAH2fxz/ANBbwn/4"
"T2sf/NRQAfZ/HP8A0FvCf/hPax/81FAB9n8c/wDQW8J/+E9rH/zUUAcB8VYPGK/DTx4bvU/DMlqPCeum4jt9D1WCd4Rp1x5iwzS+"
"IriOOUrkI8kEyK2C0bgbaAP/0f6otR/bz/ZWsvhDd/BvV/jDqfgvxjb+CG8A6xqEPwz8Y+JBoGqjSv7H1R4YF0T+ytVNsxuI4mW6"
"e0lYLKsjphWAPlxvjT+xXd+Dv2WvAuq/tTazd6X+y2Ph+PDXiO0/Z31rTfiRfL8NL/S20ODSPHcegz3/AIJsvEXh/Q9K8I/Ea00K"
"1ZPGvh9dSs5m05NUuAoB+gOift/fss/E/wATeGdF8GeP9Q1TUdK1O61+9hk8FeM9PWLS7bQ9Y06a4Euo6FbxSMt3qtlH5MbtMwlM"
"ixskTsgB7x/w0/8ABj/oZ7r/AMJ7X/8A5W0AH/DT/wAGP+hnuv8Awntf/wDlbQAf8NP/AAY/6Ge6/wDCe1//AOVtAB/w0/8ABj/o"
"Z7r/AMJ7X/8A5W0AH/DT/wAGP+hnuv8Awntf/wDlbQBz037SHwhfxZpuqL4kuTZ2/h7WrCWT+wdcBW5u9S0C4t0Ef9n+YweKyuWL"
"qmxPLAZgzoKAOh/4af8Agx/0M91/4T2v/wDytoAP+Gn/AIMf9DPdf+E9r/8A8raAD/hp/wCDH/Qz3X/hPa//APK2gA/4af8Agx/0"
"M91/4T2v/wDytoAP+Gn/AIMf9DPdf+E9r/8A8raAOc079o/4RW/iLxJqEviS5W11GPRFtH/sHXGMhsra5juMoNPLpseRAN6rvzlN"
"wBKgHR/8NP8AwY/6Ge6/8J7X/wD5W0AH/DT/AMGP+hnuv/Ce1/8A+VtAB/w0/wDBj/oZ7r/wntf/APlbQAf8NP8AwY/6Ge6/8J7X"
"/wD5W0AH/DT/AMGP+hnuv/Ce1/8A+VtAHN+Gf2j/AIRadb6rHd+JLmNrrxJ4h1CEDQdcfda3+qXFzbSEpp7BS8MisUbDoTtdVYEU"
"AdJ/w0/8GP8AoZ7r/wAJ7X//AJW0AH/DT/wY/wChnuv/AAntf/8AlbQAf8NP/Bj/AKGe6/8ACe1//wCVtAB/w0/8GP8AoZ7r/wAJ"
"7X//AJW0ANb9p74MMrL/AMJPdfMpH/Iva/3GP+gaP5/lQBheFP2kfhBpfhjw7pt54kuY7uw0PSrO6jGg67II7i3sYIpoxImnskgS"
"RGUOjMjY3KcEbgDf/wCGn/gx/wBDPdf+E9r/AP8AK2gA/wCGn/gx/wBDPdf+E9r/AP8AK2gA/wCGn/gx/wBDPdf+E9r/AP8AK2gA"
"/wCGn/gx/wBDPdf+E9r/AP8AK2gDjfiJ+0R8Jtf8B+MdE0vxFcz6lq3hvWNPsYG0PW4Vmu7qxmhgjM01hHFGHkdVLyuqLnLMACaA"
"P//ZAABQSwMEFAAGAAgAAAAhAHdDGQAXBwAA3x0AABMAAAB4bC90aGVtZS90aGVtZTEueG1s7FlNbxtFGL4j8R9Ge29jJ04aR3Wq"
"2LEbaNNGsVvU43g99k4zu7OaGSfxDbVHJCREQVyQuIGEgEqtxKWc+CmBIihS/wLvzOyud+Jx45QAAupDsjvzvN8f87FXrx3HDB0S"
"ISlPGkH1ciVAJAn5gCajRnCn17m0HiCpcDLAjCekEUyIDK5tvv3WVbyhIhITBPSJ3MCNIFIq3VhakiEMY3mZpySBuSEXMVbwKkZL"
"A4GPgG/MlpYrlbWlGNMkQAmOgW0v+vErYHZ7OKQhCTZz7m0GIhIl9UDIRFfzJhlJcywIHhvs4KCqEXIiW0ygQ8waAQga8KMeOVYB"
"YlgqmGgEFfMLljavLuGNjIipObQluo75ZXQZweBg2cgUo34htNqp1a9sF/wNgKlZXLvdbrWrBT8DwGEIllpdyjxrnfVqM+dZAtnH"
"Wd6tymql5uJL/FdmdK43m83VeqaLZWpA9rE2g1+vrNW2lh28AVn86gy+1txqtdYcvAFZ/NoMvnOlvlZz8QYUMZoczKB1QDudjHsB"
"GXK244WvA3y9ksGnKMiGIru0iCFP1Lxci/F9LjoA0ECGFU2QmqRkiENI4xaO+4JiLQBvEFyasUOhnBnSspAMBU1VI3g3xVASU34v"
"n33z8tkT9PLZ45MHT08efH/y8OHJg+8sL4dwByejMuGLLz/6/fP30W9Pvnjx6BM/XpbxP3/7wU8/fOwHQgVNNXr+6eNfnj5+/tmH"
"v379yAPfErhfhvdoTCS6RY7QPo/BNuMYV3PSF+ej6EWYOhQ4At4e1m0VOcBbE8x8uCZxnXdXQPPwAa+P7zu6diMxVtQj+UYUO8Bd"
"zlmTC68DbmhZJQ/3xsnIL1yMy7h9jA99sls4cULbHqfQNfOkdHzfioij5h7DicIjkhCF9Bw/IMRj3T1KHb/u0lBwyYcK3aOoianX"
"JT3adxJpSrRDY4jLxGczhNrxze5d1OTMZ/U2OXSRUBCYeZTvEea48ToeKxz7WPZwzMoOv4lV5FOyOxFhGdeWCiI9Ioyj9oBI6aO5"
"LcDeUtBvYOhX3rDvsknsIoWiBz6eNzHnZeQ2P2hFOE592C5NojL2HXkAKYrRHlc++C53K0S/QxxwMjfcdylxwn12I7hDR45K0wTR"
"M2PhieV1wp387U7YEBPTZaClO506psmr2jaj0LethDdtuxFswSLmK56dU816Hu5f2KK38TjZI1AVs0vUmw79pkMH//kOPa+WL74v"
"T1sxdGm9IbF7bbPzjuduvIeUsa6aMHJTmr23hAVo0IFBTWdOnaQ4iKURPOpKBgEObiSwoUGCq/eoiroRTmHfXg00k5HMWI8kSrmE"
"86IZ9vLWeNj7K3vaXNXnENs5JFa7fGCHV/Rwftwo2BitRuZMmwta0QwWFbZyJWMKtr2OsKpWamFpVaOaaYqOtMJk7WJzLgeXF6bB"
"YOFN2Nkg2A+Bl9fg3K9Fw3kHMzLQfrcxysNiovDXhCiz2hoS4QGxIXKGS96smtjlKTRjnzbP5sj5vFl4DZx2thImLebnz4JOzhlM"
"nQyEp6uJJeXaYgk6agT11eXVAIU4bQRDOOnCY5xC0KTeC2I2gvuiUAmbtWfWoinSqcV1f1ZV4fJiTsE4ZZwKqbaxjGwMzVQWKpZo"
"SVb/5dWaTraLMcDTTBbTYmUdUuQf0wJC7YaWDIckVOVgl0a07+xr1gn5WBHRjQZHqM/GYh9D+MGn2p4BlXBhYQpav8Dtmva2mXJ7"
"a9ZpyndaBmfHMUsjnHVLfTuTV5yFm35S6GDeSuqBbV7djXHnN0VX/EWZUk7j/5kpejmAG4SVgY5ACLe7AiNdKY2ACxVx6EJpRMOO"
"gHXf9A7IFrihhWlwPtwxm/+CHOr/tuYsD1PWcBBU+3SEBIXlREWCkD1oSyb7zmBWzZYey5JljExGldSVqVW7Tw4J6+keuKZ7cIAi"
"SHXTTbI2YHCn8899zyqoP9J7lHK9OZ2sWDptDfzdGxdbzGDUqb2Ezt/c/4WKxeo+Xf0svSHP18iyIXpiukuq5VXhLH71eibqNVVY"
"ZAEurbW2Y81YvLyaKwdRnLUYBov9TAr3QEj/gfWPipDZ7xV6Qe3xfeitCD4/WP8hyOpLuqtBBukGaZ/6sO+xgzaZNCvr2mzno72W"
"L9YXvFEt5J5yttZskXif09nFJsoV59TiRTo787Djazs219UQ2dMlCkPD/BxiAmO+dJW/RfH+fQj0Ntz6j5n9OiVTeDN1kO4Jk119"
"Pphkj0zaBddmnT7DaCRL9skQ0cFxfv4oPGFLyH4hybfIBq3JdKIVhCu+Q4NLmOE1qV0tC+Lls4kLCiMZWnZBbC7UfAzg+1jWuPXR"
"DvC2yVqrdXHlnmLJn3HZAsr7XeY9+SzqMntQfGWgXsNl6vjVLss8Bc6bTTz4wikwHL26pv/ComMz3aTs5h8AAAD//wMAUEsDBBQA"
"BgAIAAAAIQAsfAGw7gEAAB8EAAANAAAAeGwvc3R5bGVzLnhtbKSTTYvbMBCG74X+B6H7RknYlibY3kMhsIeWwqbQqyxLjlh9GGmc"
"2v31HVmOk7CHLfRij0ajR69ejYqnwRpyliFq70q6Wa0pkU74Rru2pD+Ph4cvlETgruHGO1nSUUb6VH38UEQYjXw5SQkEES6W9ATQ"
"7RmL4iQtjyvfSYczygfLAYehZbELkjcxLbKGbdfrz8xy7Wgm7K34F4jl4bXvHoS3HQdda6NhnFiUWLF/bp0PvDYoddg8cnFhT4M3"
"eKtF8NErWCGOeaW0kG9V7tiOIakqlHcQifC9A/QK0WmH/avzv90hTaVkrqqK+IecucHMlrKqEN74QACdQWGblHHcylzxlRtdB52S"
"ilttxpye1k1mznVW49FSFUs65l/ERdqYRdU2CcBEVaA7IIM74IDM8XHscHuHF5kxU9071W3g42b76WYBmzasitqHBhvn6sclVRVG"
"KkChQben9Aff4bf2AOhyVTSat95xgyHLkCXA4whpzEtqrl/qjj0o4np7sPDclBTbNJlwCfEgc5h5eZD4t7TM/m8sGdQ9H4k3su9E"
"L9uTdN8l/Z5eg8HOmRGk7rUB7e6B0/GR2QxXC9bpBiB1dp692I5ONFLx3sBxmSzpNf4mG93b3VL1Q589TIiSXuNc9TjdclxedvUX"
"AAD//wMAUEsDBBQABgAIAAAAIQBA1gNB0gEAAEQDAAAYAAAAeGwvd29ya3NoZWV0cy9zaGVldDEueG1sjJLBbtswDIbvA/YOgu6J"
"lKyNGyNO0TYoVqDFgnVrz7JM20Is0ZCUxcHQdx9tL8OAXHKxSZn8TP6/Vredbdgv8MGgy/hsKjkDp7Ewrsr4zx+PkxvOQlSuUA06"
"yPgRAr9df/60OqDfhRogMiK4kPE6xjYVIugarApTbMHRlxK9VZFSX4nQelDF0GQbMZdyIawyjo+E1F/CwLI0Gjao9xZcHCEeGhVp"
"/lCbNpxoVl+Cs8rv9u1Eo20JkZvGxOMA5czq9Kly6FXe0N7d7ErpE3tIzvDWaI8ByzglnBgHPd95KZaCSOtVYWiDXnbmocz43YyL"
"9WoQ583AIfwXs6jyV2hARyjII8567XPEXV/4REeybxVnvY+D9lvPchXgAZt3U8SaAORxAaXaN/E7Hr6CqepIp9e0Xb9kWhw3EDSp"
"+xc8cDcqKvpJqyp4Ub4yLrAGyr5kmlCnHyFjErEdxswxRrRDWJPxQAbLKRWXiPGUEBO6+Bzi8GZ7bzL+e3El5Tz5MpvcLe7l5Lp/"
"zBeJnCTJfHafPMjlQsqPkxm2u8wJq7SATsNw827Gm7de2S7dPr+xFyzIZBLmm4Mt7TjE769a9d6P8tKYJPJpWPHv/q//AAAA//8D"
"AFBLAwQUAAYACAAAACEAUwImS0oBAABzAgAAEQAIAWRvY1Byb3BzL2NvcmUueG1sIKIEASigAAEAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAlJJNTsMwFIT3SNwh8j6xk5YKRUkqQdUVlZBaBGJn7NfWInYs25D2SJyDi+H8NAS1G5b2zPs88+RsfpBl8AnG"
"ikrlKI4ICkCxigu1y9HTZhneosA6qjgtKwU5OoJF8+L6KmM6ZZWBR1NpME6ADTxJ2ZTpHO2d0ynGlu1BUht5h/LitjKSOn80O6wp"
"e6c7wAkhMyzBUU4dxQ0w1AMR9UjOBqT+MGUL4AxDCRKUsziOYvzrdWCkvTjQKiOnFO6ofac+7pjNWScO7oMVg7Gu66ietDF8/hi/"
"rB7WbdVQqGZXDFCRcZYyA9RVplh/f71R63ekgoXwmU2GR2qzydLLK7/0rQB+d7w0cG7yL7SFumeABz5i2hU6Kc+T+8VmiYqExLOQ"
"TEMSb+JpSpI0Ia9Nhj/zTeTuQvZJ/kOc3IyIJ0CR4bNvUvwAAAD//wMAUEsDBBQABgAIAAAAIQCcFKQQmgEAAC4DAAAQAAgBZG9j"
"UHJvcHMvYXBwLnhtbCCiBAEooAABAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAJySTW/bMAyG7wP6HwTdGzltUQyBrKJI"
"V/TQYgGS9q7KdCxMlgSJMeL9+tE2sjjbTrvxSy8fUpQPx9axDlK2wZd8uSg4A29CZf2+5O+75+uvnGXUvtIueCh5D5k/qKsvcpNC"
"hIQWMiMJn0veIMaVENk00Oq8oLSnTB1Sq5HctBehrq2Bp2AOLXgUN0VxL+CI4CuoruNvQT4prjr8X9EqmIEvf+z6SMBKPsborNFI"
"U6o3a1LIoUb2po31GHLDvh0NOCnmZZI4t2AOyWKvCinmrtwa7WBNLVStXQYpzgH5AnpY30bblJXscNWBwZBYtj9pgTecfeoMA1jJ"
"O52s9kiAQ9nkjLaLGZN6hoN1jjZcAaOG5kCIVDglR3P+Zm7bO7UcC8i4LBwEJiBKXKLuLFKz7/VGJ/wH+XJOPjJM3DPWqeecbxyd"
"Ov2hvQ5t1L5Xm+B6E3wGS6OdgvLV+h/5Pe7Ck0Y4bfgyKLeNTlDRp5zy54B8oeUmN4isG+33UJ1q/k4Ml/Exnb9a3i2K24K+ehaT"
"4nzo6hcAAAD//wMAUEsBAi0AFAAGAAgAAAAhABNY/HpaAQAAPAQAABMAAAAAAAAAAAAAAAAAAAAAAFtDb250ZW50X1R5cGVzXS54"
"bWxQSwECLQAUAAYACAAAACEAfcxUng0BAADdAgAACwAAAAAAAAAAAAAAAACTAwAAX3JlbHMvLnJlbHNQSwECLQAUAAYACAAAACEA"
"0D9k3eEAAAAtAgAAGgAAAAAAAAAAAAAAAADRBgAAeGwvX3JlbHMvd29ya2Jvb2sueG1sLnJlbHNQSwECLQAUAAYACAAAACEA2xYh"
"ss0BAADpAgAADwAAAAAAAAAAAAAAAADyCAAAeGwvd29ya2Jvb2sueG1sUEsBAi0ACgAAAAAAAAAhAAm1nvVESQAAREkAABcAAAAA"
"AAAAAAAAAAAA7AoAAGRvY1Byb3BzL3RodW1ibmFpbC5qcGVnUEsBAi0AFAAGAAgAAAAhAHdDGQAXBwAA3x0AABMAAAAAAAAAAAAA"
"AAAAZVQAAHhsL3RoZW1lL3RoZW1lMS54bWxQSwECLQAUAAYACAAAACEALHwBsO4BAAAfBAAADQAAAAAAAAAAAAAAAACtWwAAeGwv"
"c3R5bGVzLnhtbFBLAQItABQABgAIAAAAIQBA1gNB0gEAAEQDAAAYAAAAAAAAAAAAAAAAAMZdAAB4bC93b3Jrc2hlZXRzL3NoZWV0"
"MS54bWxQSwECLQAUAAYACAAAACEAUwImS0oBAABzAgAAEQAAAAAAAAAAAAAAAADOXwAAZG9jUHJvcHMvY29yZS54bWxQSwECLQAU"
"AAYACAAAACEAnBSkEJoBAAAuAwAAEAAAAAAAAAAAAAAAAABPYgAAZG9jUHJvcHMvYXBwLnhtbFBLBQYAAAAACgAKAIMCAAAfZQAA"
"AAA="))



import collections.abc
from itertools import chain, islice
import logging
import zipfile

import zipstream

from . import render
from .xlsx_template import DEFAULT_TEMPLATE


logger = logging.getLogger(__name__)

EXCEL_WORKSHEETS_PATH = 'xl/worksheets/'


def stream_queryset_as_xlsx(
        qs,
        xlsx_template=None,
        serializer=None,
        batch_size=1000,
        encoding='utf-8',
    ):
    """
    Iterate over qs by batch (typically a Django queryset) and stream the bytes of the
    xlsx document generated from the data.

    This function can typically be used to stream data extracted from a database by batch,
    making many small database requests instead of one big request which could timeout.

    Args:
        qs (Iterable): an iterable containing the rows (typically a Django queryset)
        xlsx_template (Optional[BytesIO]): an in memory xlsx file template containing
            the header (optional) and the first row used to infer data types for each column.
            If not provided, all cells will be formatted as text.
        serializer (Optional[Callable]): a function applied to each batch of rows to transform
            them before saving them to the xlsx document (defaults to identity).
        batch_size (Optional[int]): the size of each batch of rows
        encoding (Optional[str]): the file encoding

    Returns:
        Iterable: A streamable xlsx file

    Note:
        If the xlsx template contains more than one row, the first row is kept as is in the final
        xlsx file (header row), and the second one is used as a template for all the generated rows.
    """
    serializer = serializer or (lambda x: x)

    batches = serialize_queryset_by_batch(qs, serializer=serializer, batch_size=batch_size)

    try:
        zip_template = zipfile.ZipFile(xlsx_template, mode='r')
    except Exception:  # pylint: disable=broad-except
        logger.debug('Template is not a valid Excel file, ignoring it. Every cell will be saved as text.')
        zip_template = zipfile.ZipFile(DEFAULT_TEMPLATE, mode='r')

    sheet_name = get_first_sheet_name(zip_template)
    if sheet_name is None:
        logger.debug('Template is not a valid Excel file, ignoring it. Every cell will be saved as text.')
        zip_template = zipfile.ZipFile(DEFAULT_TEMPLATE, mode='r')
        sheet_name = get_first_sheet_name(zip_template)

    xlsx_sheet_string = zip_template.read(sheet_name).decode(encoding)

    zipped_stream = zip_to_zipstream(zip_template, exclude=[sheet_name])
    # Write the generated worksheet to the stream
    worksheet_stream = render.render_worksheet(batches, xlsx_sheet_string, encoding)
    zipped_stream.write_iter(
        arcname=sheet_name,
        iterable=worksheet_stream,
        compress_type=zipstream.ZIP_DEFLATED
    )

    return zipped_stream


def serialize_queryset_by_batch(qs, serializer, batch_size):
    if isinstance(qs, collections.abc.Iterator):
        qs_slices = _chunks(qs, batch_size)
        for batch in qs_slices:
            yield serializer(list(batch))
    else:
        start, last_batch = 0, []
        while start == 0 or len(last_batch) == batch_size:
            last_batch = list(qs[start:start + batch_size])  # force queryset evaluation
            yield serializer(last_batch)
            start += batch_size


def _chunks(iterable, size):
    iterator = iter(iterable)
    for first in iterator:
        yield chain([first], islice(iterator, size - 1))


def zip_to_zipstream(zip_file, only=None, exclude=None):
    """
    args:
        zip_file (ZipFile): the original zipfile.ZipFile
        only (list): the file names of the files to be included in the stream
        exclude (list): the file names of the files to be excluded in the stream
        ..note: only and exclude cannot be used at the same time
    """
    only = only or []
    exclude = exclude or []
    if only and exclude:
        raise AttributeError('`only` and `exclude` cannot be used at the same time')

    file_names = zip_file.namelist()
    if only:
        file_names = [name for name in file_names if name in only]
    elif exclude:
        file_names = [name for name in file_names if name not in exclude]

    zip_stream = zipstream.ZipFile(mode='w', compression=zipstream.ZIP_DEFLATED)
    for file_name in file_names:
        zip_stream.write_iter(
            arcname=file_name,
            iterable=iter([zip_file.read(file_name)]),
            compress_type=zipstream.ZIP_DEFLATED,
        )
    return zip_stream


def get_first_sheet_name(xlsx_zipfile):
    try:
        return next(
            path
            for path in xlsx_zipfile.namelist()
            if path.startswith(EXCEL_WORKSHEETS_PATH) and path.endswith('.xml')
        )
    except StopIteration:
        return None



import datetime
import logging
import re
from xml.etree import ElementTree as ETree


logger = logging.getLogger(__name__)


OPENXML_NS = 'http://schemas.openxmlformats.org/spreadsheetml/2006/main'
OPENXML_NS_R = 'http://schemas.openxmlformats.org/officeDocument/2006/relationships'
OPENXML_COLUMN_RE = re.compile(r'([A-Z]+)[0-9]+')


def _timezone_helper():
    _timezone_helper.timezone = None
    def get():
        return _timezone_helper.timezone
    def set_(value):
        _timezone_helper.timezone = value
    return get, set_


get_export_timezone, set_export_timezone = _timezone_helper()


def render_worksheet(rows_batches, openxml_sheet_string, encoding='utf-8'):
    """
        Render a collection of row batches to open xml.

        args:
            rows_batches (iterable): each element is a list of lists containing the row values
            openxml_sheet_string (str): a template for the final sheet containing the header and an example row
    """
    header = (
        '<worksheet xmlns="{ns}" xmlns:r="{ns_r}">\n'
        ' <sheetData>\n'
        .format(ns=OPENXML_NS, ns_r=OPENXML_NS_R)
    ).encode(encoding)
    footer = (
        ' </sheetData>\n'
        '</worksheet>\n'
    ).encode(encoding)

    yield header
    current_line = 1
    header_tree, row_template = get_header_and_row_template(openxml_sheet_string)  # pylint: disable=unbalanced-tuple-unpacking
    if header_tree is not None:
        yield ETree.tostring(header_tree, encoding=encoding)
        current_line += 1
    for rows in rows_batches:
        rendered_rows, lines = render_rows(rows, row_template, start_line=current_line, encoding=encoding)
        yield rendered_rows
        current_line += lines
    yield footer


def render_rows(rows, row_template, start_line, encoding='utf-8'):
    """
        Return a collection of open xml rows as bytes.

        The output is a byte string like:

            <row r='2'>…</row>
            <row r='3'>…</row>
            …

        args:
            rows (list): a list of list containing the row values
            row_template (xml.ElementTree): a template used for each row
            start_line (int): the line of the first row in the returned xml

        ..note: This function updates row_template each time it is called.
    """
    lines = 0
    rendered_rows = []
    for i, row in enumerate(rows, start_line):
        rendered_rows.append(render_row(row, row_template, i, encoding))
        lines += 1
    return b'\n'.join(rendered_rows), lines


def render_row(row_values, row_template, line, encoding='utf-8'):
    """
        Return an openxml row as bytes using row_template as a model, and row_values for the values.

        args:
            row_values (list): the list of values to update the row
            row_template (xml.ElementTree): a template for the current row
            line (int): the line of the current row

        ..note: This function updates row_template each time it is called.
    """
    reset_memory = line < 3  # with a header, the first call to render_row can be with line = 2
    if row_template is None:
        row_template = get_default_template(row_values, reset_memory)
    cells = list(row_template)
    if len(cells) != len(row_values):
        logger.debug(
            '``len(row_values)`` do not match the number of cells in ``row_template``. '
            'Ignoring template (all cells will be stored as text).'
        )
        row_template = get_default_template(row_values, reset_memory)
        cells = list(row_template)

    for value, cell_template in zip(row_values, cells):
        update_cell(cell_template, line, value)
    row_template.set('r', str(line))
    return ETree.tostring(row_template, encoding=encoding)


def update_cell(cell, line, value):
    """
        Update cell with a new line and a new value.

        The value must be compatible with the cell type (numeric, boolean or text).
        The function raises if this is not the case.
        Updating a cell with a None value sets cell.text to the empty string.
    """
    column = get_column(cell)
    cell_type = cell.attrib.get('t', 'n')
    update_function = {
        'n': _update_numeric_cell,
        'b': _update_boolean_cell,
    }.get(cell_type, _update_text_cell)

    try:
        update_function(cell, value)
    except Exception as e:  # pylint: disable=broad-except
        args = e.args or ['']
        msg = "(column '%s', line '%s') data does not match template: %s" % (column, line, args[0])
        logger.debug(msg)
    cell.set('r', '%s%s' % (column, line))


def _update_boolean_cell(cell, value):
    if value is not None and not isinstance(value, bool):
        raise AttributeError("expected a boolean got %s." % value)
    next(child for child in cell if child.tag == 'v').text = '' if value is None else str(int(value))


def _update_numeric_cell(cell, value):
    if value is None:
        cell_text = ''
    else:
        try:
            cell_text = str(datetime_to_excel_datetime(value))
        except TypeError:
            cell_text = str(value)
        try:
            float(cell_text)
        except Exception as e:  # pylint: disable=broad-except
            raise AttributeError("expected a numeric or date like value got %s." % cell_text) from e
    next(child for child in cell if child.tag == 'v').text = cell_text


def _update_text_cell(cell, value):
    if cell.get('t') != 'inlineStr':
        # write all the strings 'inline' to avoid messing up with
        # a string reference file in the final xlsx file
        cell.clear()
        cell.set('t', 'inlineStr')
        ETree.SubElement(ETree.SubElement(cell, 'is'), 't')
    updated_text = '' if value is None else str(value)
    next(child for child in cell.iter() if child.tag == 't').text = updated_text


def datetime_to_excel_datetime(dt_obj, date_1904=False):
    """
        Convert a datetime object to an Excel serial date and time. The integer
        part of the number stores the number of days since the epoch and the
        fractional part stores the percentage of the day.
        Credits: Taken from https://github.com/jmcnamara/XlsxWriter
    """

    if date_1904:
        # Excel for Mac date epoch.
        epoch = datetime.datetime(1904, 1, 1)
    else:
        # Default Excel epoch.
        epoch = datetime.datetime(1899, 12, 31)

    # convert to the export timezone before making the datetimes naive (excel has no notion of timezone)
    if getattr(dt_obj, 'tzinfo', None) is not None:
        timezone = get_export_timezone()
        if timezone is not None:
            dt_obj = dt_obj.astimezone(timezone)
        dt_obj = dt_obj.replace(tzinfo=None)

    # We handle datetime .datetime, .date and .time objects but convert
    # them to datetime.datetime objects and process them in the same way.
    if isinstance(dt_obj, datetime.datetime):
        delta = dt_obj - epoch
    elif isinstance(dt_obj, datetime.date):
        dt_obj = datetime.datetime.fromordinal(dt_obj.toordinal())
        delta = dt_obj - epoch
    elif isinstance(dt_obj, datetime.time):
        dt_obj = datetime.datetime.combine(epoch, dt_obj)
        delta = dt_obj - epoch
    elif isinstance(dt_obj, datetime.timedelta):
        delta = dt_obj
    else:
        raise TypeError("Unknown or unsupported datetime type")

    # Convert a Python datetime.datetime value to an Excel date number.
    excel_time = (delta.days
                  + (float(delta.seconds)
                     + float(delta.microseconds) / 1E6)
                  / (60 * 60 * 24))

    # Special case for datetime where time only has been specified and
    # the default date of 1900-01-01 is used.
    if (not isinstance(dt_obj, datetime.timedelta)
            and dt_obj.isocalendar() == (1900, 1, 1)):
        excel_time -= 1

    # Account for Excel erroneously treating 1900 as a leap year.
    if not date_1904 and excel_time > 59:
        excel_time += 1

    return excel_time


def rm_namespace(xml_element):
    """Remove namespace in the ``xml_element`` and all of its children."""
    for el in xml_element.iter():
        if '}' in el.tag:
            el.tag = el.tag.split('}', 1)[1]  # strip all namespaces


def count_cells(row):
    """Count the number of cells in a openxml row"""
    return len(list(child for child in row if child.tag == 'c'))


def get_column(cell):
    """Return the column attribute ([A-Z]+) of the openxml cell."""
    match = re.match(OPENXML_COLUMN_RE, cell.get('r', ''))
    if match is None:
        raise AttributeError('The cell attribute is not a valid OpenXML column name: %s' % cell.get('r'))
    return match.group(1)


def _get_column_letter(col_idx):
    """Convert a column number into a column letter (3 -> 'C')

    Right shift the column col_idx by 26 to find column letters in reverse
    order.  These numbers are 1-based, and can be converted to ASCII
    ordinals by adding 64.

    Credits: openpyxl library
    """
    # these indicies corrospond to A -> ZZZ and include all allowed
    # columns
    if not 1 <= col_idx <= 18278:
        raise ValueError("Invalid column index {}".format(col_idx))
    letters = []
    while col_idx > 0:
        col_idx, remainder = divmod(col_idx, 26)
        # check for exact division and borrow if needed
        if remainder == 0:
            remainder = 26
            col_idx -= 1
        letters.append(chr(remainder+64))
    return ''.join(reversed(letters))


def get_header_and_row_template(openxml_sheet):
    """
        Extract the header (potentially None) and the first row from openxml_sheet
        args:
            openxml_sheet (str): the openxml sheet imported as unicode
        return (tuple): a tuple of (header_tree, row_template_tree) ElementTree objects
    """
    tree = ETree.fromstring(openxml_sheet)
    rm_namespace(tree)
    sheet_data = next(child for child in tree if child.tag == 'sheetData')
    header_and_row_template = []
    for child in sheet_data:
        if child.tag == 'row':
            header_and_row_template.append(child)
        if len(header_and_row_template) == 2:
            header, row = header_and_row_template  # pylint: disable=unbalanced-tuple-unpacking
            if count_cells(header) != count_cells(row):
                logger.debug(
                    'Header and row template do not have the same number of cells. '
                    'Ignoring template (all cells will be stored as text).'
                )
                header_and_row_template = [None, None]
            break
    else:
        header_and_row_template = [None] + (header_and_row_template or [None])
    return tuple(header_and_row_template)


def get_default_template(row_values, reset_memory=False):
    """
        Return the default template row.
        It has only text cells, and as many columns as in row_values.
    """
    get_default_template._memoized = [] if reset_memory else getattr(get_default_template, '_memoized', [])
    if get_default_template._memoized:
        return get_default_template._memoized[0]

    root = ETree.Element('row', {'r': '1'})
    for i in range(1, len(row_values) + 1):
        el_t = ETree.Element('t')
        el_t.text = 'Default'
        el_is = ETree.Element('is')
        el_is.append(el_t)
        cell = ETree.Element('c', {'r': '%s%s' % (_get_column_letter(i), 1), 't': 'inlineStr'})
        cell.append(el_is)
        root.append(cell)

    get_default_template._memoized.append(root)
    return root



from setuptools import setup, find_packages

PACKAGE = 'xlsx_streaming'
description = 'Export your data as an xlsx stream'


def get_long_description():
    with open('README.rst') as readme_file:
        return readme_file.read()


REQUIREMENTS = [
    'zipstream>=1.1.3',
]

setup(
    name=PACKAGE,
    version='1.1.0',
    description=description,
    long_description=get_long_description(),
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    keywords=['xlsx', 'excel', 'streaming'],
    author='Polyconseil',
    author_email='opensource+%s@polyconseil.fr' % PACKAGE,
    url='https://github.com/Polyconseil/%s/' % PACKAGE,
    license='GNU GPLv3',
    packages=find_packages(exclude=['docs', 'tests']),
    setup_requires=[
        'setuptools',
    ],
    install_requires=REQUIREMENTS,
    test_suite='tests',
)
